"ensembleSize.ensembleData" <-
function(x) 
{ 
 attr(x, "ensembleSize")
}

